Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(608)

Unified Diff: runtime/observatory/tests/service/debugging_inlined_finally_test.dart

Issue 1217823009: Make VM event streams look like real dart streams. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: merge with master Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/observatory/tests/service/debugging_inlined_finally_test.dart
diff --git a/runtime/observatory/tests/service/debugging_inlined_finally_test.dart b/runtime/observatory/tests/service/debugging_inlined_finally_test.dart
index 85d910ba2f6a14c6e14435953895b11ee104e2b1..b3d51ee902c4e60395a3db3b54ae6b5f14c47e78 100644
--- a/runtime/observatory/tests/service/debugging_inlined_finally_test.dart
+++ b/runtime/observatory/tests/service/debugging_inlined_finally_test.dart
@@ -6,7 +6,6 @@
import 'package:observatory/service_io.dart';
import 'package:unittest/unittest.dart';
import 'test_helper.dart';
-import 'dart:async';
import 'dart:developer';
testFunction() {
@@ -17,13 +16,13 @@ testFunction() {
try {
for (int i = 0; i < 10; i++) {
var x = () => i + a + b;
- return x; // line 20
+ return x; // line 19
}
} finally {
- b = 10; // line 23
+ b = 10; // line 22
}
} finally {
- a = 1; // line 26
+ a = 1; // line 25
}
}
@@ -45,32 +44,32 @@ hasStoppedAtBreakpoint,
// Add 3 breakpoints.
{
- var result = await isolate.addBreakpoint(script, 20);
+ var result = await isolate.addBreakpoint(script, 19);
expect(result is Breakpoint, isTrue);
Breakpoint bpt = result;
expect(bpt.type, equals('Breakpoint'));
expect(bpt.location.script.id, equals(script.id));
- expect(bpt.location.script.tokenToLine(bpt.location.tokenPos), equals(20));
+ expect(bpt.location.script.tokenToLine(bpt.location.tokenPos), equals(19));
expect(isolate.breakpoints.length, equals(1));
}
{
- var result = await isolate.addBreakpoint(script, 23);
+ var result = await isolate.addBreakpoint(script, 22);
expect(result is Breakpoint, isTrue);
Breakpoint bpt = result;
expect(bpt.type, equals('Breakpoint'));
expect(bpt.location.script.id, equals(script.id));
- expect(bpt.location.script.tokenToLine(bpt.location.tokenPos), equals(23));
+ expect(bpt.location.script.tokenToLine(bpt.location.tokenPos), equals(22));
expect(isolate.breakpoints.length, equals(2));
}
{
- var result = await isolate.addBreakpoint(script, 26);
+ var result = await isolate.addBreakpoint(script, 25);
expect(result is Breakpoint, isTrue);
Breakpoint bpt = result;
expect(bpt.type, equals('Breakpoint'));
expect(bpt.location.script.id, equals(script.id));
- expect(bpt.location.script.tokenToLine(bpt.location.tokenPos), equals(26));
+ expect(bpt.location.script.tokenToLine(bpt.location.tokenPos), equals(25));
expect(isolate.breakpoints.length, equals(3));
}
@@ -81,42 +80,42 @@ resumeIsolate,
hasStoppedAtBreakpoint,
// We are at the breakpoint on line 20.
(Isolate isolate) async {
ServiceMap stack = await isolate.getStack();
expect(stack.type, equals('Stack'));
expect(stack['frames'].length, greaterThanOrEqualTo(1));
Script script = stack['frames'][0].location.script;
- expect(script.tokenToLine(stack['frames'][0].location.tokenPos), equals(20));
+ expect(script.tokenToLine(stack['frames'][0].location.tokenPos), equals(19));
},
resumeIsolate,
hasStoppedAtBreakpoint,
// We are at the breakpoint on line 23.
(Isolate isolate) async {
ServiceMap stack = await isolate.getStack();
expect(stack.type, equals('Stack'));
expect(stack['frames'].length, greaterThanOrEqualTo(1));
Script script = stack['frames'][0].location.script;
- expect(script.tokenToLine(stack['frames'][0].location.tokenPos), equals(23));
+ expect(script.tokenToLine(stack['frames'][0].location.tokenPos), equals(22));
},
resumeIsolate,
hasStoppedAtBreakpoint,
// We are at the breakpoint on line 26.
(Isolate isolate) async {
ServiceMap stack = await isolate.getStack();
expect(stack.type, equals('Stack'));
expect(stack['frames'].length, greaterThanOrEqualTo(1));
Script script = stack['frames'][0].location.script;
- expect(script.tokenToLine(stack['frames'][0].location.tokenPos), equals(26));
+ expect(script.tokenToLine(stack['frames'][0].location.tokenPos), equals(25));
},
resumeIsolate,
« no previous file with comments | « runtime/observatory/tests/service/debugger_location_test.dart ('k') | runtime/observatory/tests/service/debugging_test.dart » ('j') | no next file with comments »
@@ -81,42 +80,42 @@ resumeIsolate,
hasStoppedAtBreakpoint,
-// We are at the breakpoint on line 20.
+// We are at the breakpoint on line 19.
(Isolate isolate) async {
ServiceMap stack = await isolate.getStack();
@@ -81,42 +80,42 @@ resumeIsolate,
resumeIsolate,
hasStoppedAtBreakpoint,
-// We are at the breakpoint on line 23.
+// We are at the breakpoint on line 22.
(Isolate isolate) async {
ServiceMap stack = await isolate.getStack();
@@ -81,42 +80,42 @@ resumeIsolate,
resumeIsolate,
hasStoppedAtBreakpoint,
-// We are at the breakpoint on line 26.
+// We are at the breakpoint on line 25.
(Isolate isolate) async {
ServiceMap stack = await isolate.getStack();

Powered by Google App Engine
This is Rietveld 408576698